@@ -31,6 +31,7 @@ class ResourceMeta(type):
     """Updates the TastyApi.auth for the class and all instances."""
 
     _classes = []
+    _factory = None
 
     def __new__(mcs, name, bases, classdict):
         try:
@@ -53,8 +54,25 @@ class ResourceMeta(type):
         return obj
 
     def __len__(cls):
-        response = next(iter(cls.api().get(cls.resource(), cls.schema(), limit=1)))
-        return response['meta']['total_count']
+        return cls.count()
+
+    def __getattr__(cls, name):
+        if name not in cls.schema().list_endpoints():
+            raise AttributeError(name)
+        def _call_resource_classmethod(*args, **kwargs):
+            result = cls.api().list_endpoint(cls.resource(), name, cls.schema(), *args, **kwargs)
+            try:
+                return cls.create_related_resource(result)
+            except (AttributeError, IndexError):
+                return result
+        return _call_resource_classmethod
+
+    @staticmethod
+    def _get_resource_type(details):
+        try:
+            return details['resource_uri'].split('/')[-3]
+        except TypeError:
+            return details.split('/')[-3]
 
     def _set_api_auth(cls, auth):
         cls._auth = auth
@@ -68,6 +86,16 @@ class ResourceMeta(type):
 
     auth = property(lambda cls: cls._auth, _set_auth)
 
+    def create_related_resource(cls, related_details):
+        """Create a new resource from the related field."""
+        resource_type = cls._get_resource_type(related_details)
+        resource_class = getattr(cls._factory, resource_type)
+        # Tastypie can either return a dict of fields for a resource, or simply
+        # its URI. We want to pass its fields to the new Resource.
+        if not isinstance(related_details, dict):
+            related_details = resource_class.api().details(related_details, resource_class.schema())
+        return resource_class(_details=related_details)
+
     def resource(cls):
         """Return the resource name of this class."""
         if cls._class_resource is None:
@@ -156,9 +184,17 @@ class ResourceMeta(type):
             pass
         return result
 
-    def count(cls):
-        """Return the number of records for this resource."""
-        return len(cls)
+    def count(cls, **kwargs):
+        """Return the number of records for this resource.
+
+        :param kwargs: Keywors arguments to filter the search.
+        :type kwargs: dict
+        :returns: The number of records for this resource.
+        :rtype: int
+        """
+        kwargs['limit'] = 1
+        response = next(iter(cls.api().get(cls.resource(), cls.schema(), **kwargs)))
+        return response['meta']['total_count']
 
     def bulk(cls, create=None, update=None, delete=None):
         """Create, update, and delete to multiple resources in a single request.
@@ -172,10 +208,10 @@ class ResourceMeta(type):
         attempt to use them afterwards will raise an exception.
 
         Because of the potentially large size of bulk updates, the API will
-        respond with a 202 before completing the request (see `here
-        <http://en.wikipedia.org/wiki/List_of_HTTP_status_codes#2xx_Success>_`
-        and `here <http://django-tastypie.readthedocs.org/en/latest/interacting.html#bulk-operations>_`
-        ). This means it's possible for the request to fail without us knowing.
+        respond with a 202 before completing the request (see `wikipedia
+        <http://en.wikipedia.org/wiki/List_of_HTTP_status_codes#2xx_Success>`_,
+        and `tastypie <http://django-tastypie.readthedocs.org/en/latest/interacting.html#bulk-operations>`_).
+        This means it's possible for the request to fail without us knowing.
         So, while this method can be used for a sizeable optimization, there is
         a pitfall: You have been warned!
 
